@@ -23,7 +23,7 @@ from .utils import read_yaml
 
 from .database import open_database
 
-__version__ = "0.7.10"
+__version__ = "0.7.11"
 
 log = logging.getLogger(__name__)
 
@@ -51,7 +51,7 @@ class ColorScheme(object):
 
         color = getattr(self._term, name, None)
 
-        if not color:
+        if color is None:
             raise KeyError("Missing color '{0}'".format(name))
 
         return color
